@@ -7,8 +7,8 @@
 ;; Created: March 18, 2025
 ;; URL: https://github.com/vale981/overleaf.el
 ;; Package-Requires: ((emacs "29.4") (plz "0.9") (websocket "1.15") (webdriver "0.1") (posframe "1.4.4"))
-;; Package-Version: 20250728.2103
-;; Package-Revision: 515e45df1bec
+;; Package-Version: 20260122.1439
+;; Package-Revision: 933a0185e9d1
 ;; Keywords: hypermedia, tex, comm
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;; This file is not part of GNU Emacs.
@@ -94,6 +94,24 @@ To be used with `overleaf-cookies'."
       (insert-file-contents (expand-file-name file))
       (read (string-trim (buffer-string))))))
 
+(defun overleaf--sqlite-select-firefox-overleaf-cookies (dbfile)
+  "Return Overleaf cookies from Firefox cookie DBFILE.
+Returns a list of (host cookie-string expiry)."
+  (let ((db (sqlite-open dbfile)))
+    (unwind-protect
+        (mapcar
+         (lambda (row)
+           (pcase-let* ((`(,domain ,name ,value ,expiry) row))
+             `(,domain
+               ,(format "%s=%s" name value)
+               ,expiry)))
+         (sqlite-select
+          db
+          (concat
+           "SELECT host, name, value, expiry FROM moz_cookies "
+           "WHERE name = 'overleaf_session2' OR name = 'overleaf.sid'")))
+      (sqlite-close db))))
+
 ;;;###autoload
 (cl-defun overleaf-read-cookies-from-firefox (&key (firefox-folder "~/.mozilla/firefox/") (profile nil))
   "Make a cookie saving function reading the database at FIREFOX-FOLDER.
@@ -119,10 +137,10 @@ profile.  Otherwise prompt."
                       (mapcar (lambda (block)
                                 (save-match-data
                                   (when-let*
-                                      ((path (progn (string-match "^Path=\\(.*?\\)$" block)
-                                                    (match-string 1 block)))
-                                       (name (progn (string-match "^Name=\\(.*?\\)$" block)
-                                                    (match-string 1 block))))
+                                      ((path (and (string-match "^Path=\\(.*?\\)$" block)
+                                                  (match-string 1 block)))
+                                       (name (and (string-match "^Name=\\(.*?\\)$" block)
+                                                  (match-string 1 block))))
                                     `(:fields (,name) :data ,path))))
                               profile-blocks)))
 
@@ -138,20 +156,30 @@ profile.  Otherwise prompt."
                (cookie-file
                 (if profile
                     (expand-file-name (concat firefox-folder "/" profile "/cookies.sqlite"))
-                  (user-error "Profile does not exist")))
-               (db (sqlite-open cookie-file))
-               (result
-                (mapcar
-                 (lambda (row)
-                   (pcase-let* ((`(,domain ,name ,value ,expiry) row))
-                     `(,domain
-                       ,(format "%s=%s" name value)
-                       ,expiry)))
-                 (sqlite-select
-                  db "SELECT host, name, value, expiry FROM moz_cookies WHERE name = 'overleaf_session2' OR name = 'overleaf.sid'"))))
-
-          (sqlite-close db)
-          result)
+                  (user-error "Profile does not exist"))))
+          (condition-case err
+              (overleaf--sqlite-select-firefox-overleaf-cookies cookie-file)
+            (sqlite-error
+             (condition-case _err
+                 (let* ((temp-dir (make-temp-file "overleaf-firefox-cookies." t))
+                        (temp-cookie-file (expand-file-name "cookies.sqlite" temp-dir))
+                        (cookie-file-wal (concat cookie-file "-wal"))
+                        (temp-cookie-file-wal (concat temp-cookie-file "-wal"))
+                        (cookie-file-shm (concat cookie-file "-shm"))
+                        (temp-cookie-file-shm (concat temp-cookie-file "-shm")))
+                   (unwind-protect
+                       (progn
+                         (copy-file cookie-file temp-cookie-file t t)
+                         (when (file-exists-p cookie-file-wal)
+                           (ignore-errors
+                             (copy-file cookie-file-wal temp-cookie-file-wal t t)))
+                         (when (file-exists-p cookie-file-shm)
+                           (ignore-errors
+                             (copy-file cookie-file-shm temp-cookie-file-shm t t)))
+                         (overleaf--sqlite-select-firefox-overleaf-cookies temp-cookie-file))
+                     (ignore-errors (delete-directory temp-dir t))))
+               (sqlite-error
+                (signal 'sqlite-error err))))))
       (user-error "Sqlite not available!"))))
 
 (defvar overleaf-save-cookies (lambda (cookies)
